# Changelog

## [0.1.0] - 2023-08-14

### Changed

- Change naming scheme for 'relaxed' output scenarios: All path scenario names are now joined using ' > ' rather than using ' > ' for organizational scenarios and ' / ' for validated scenarios.

## [0.0.2] - 2023-08-11

### Changed

- Change naming of 'relaxed' scenarios to include the names of all scenarios in the scenario path (root to leaf scenario) that are either 'organizational' scenarios or 'validated' scenarios (scenarios for which assertions were written)

## [0.0.1] - 2023-08-08

- Initial release
